pub fn uncompress(src: &[u8]) -> Result<Vec<usize>, Error>Expand description
Uncompresses a stack trace.
This function assumes that the uncompressed pointers will fit in usize, which is always true if the stack trace was generated on the same architecture.